@@ -9,17 +9,17 @@
 
 #include <QtTest>
 
-#include <QMap>
-#include <QMimeType>
-#include <QMimeDatabase>
 #include "../settings_core.h"
 #include "core/document.h"
-#include <core/page.h>
+#include <QMap>
+#include <QMimeDatabase>
+#include <QMimeType>
 #include <core/form.h>
+#include <core/page.h>
 
 #include "../generators/poppler/config-okular-poppler.h"
 
-class VisibilityTest: public QObject
+class VisibilityTest : public QObject
 {
     Q_OBJECT
 
@@ -32,21 +32,21 @@ private slots:
     void testActionVisibility();
 
 private:
-    void verifyTargetStates( bool visible );
+    void verifyTargetStates(bool visible);
 
     Okular::Document *m_document;
-    QMap<QString, Okular::FormField*> m_fields;
+    QMap<QString, Okular::FormField *> m_fields;
 };
 
 void VisibilityTest::initTestCase()
 {
-    Okular::SettingsCore::instance( QStringLiteral("visibilitytest") );
-    m_document = new Okular::Document( nullptr );
+    Okular::SettingsCore::instance(QStringLiteral("visibilitytest"));
+    m_document = new Okular::Document(nullptr);
 
-    const QString testFile = QStringLiteral( KDESRCDIR "data/visibilitytest.pdf" );
+    const QString testFile = QStringLiteral(KDESRCDIR "data/visibilitytest.pdf");
     QMimeDatabase db;
-    const QMimeType mime = db.mimeTypeForFile( testFile );
-    QCOMPARE( m_document->openDocument( testFile, QUrl(), mime), Okular::Document::OpenSuccess );
+    const QMimeType mime = db.mimeTypeForFile(testFile);
+    QCOMPARE(m_document->openDocument(testFile, QUrl(), mime), Okular::Document::OpenSuccess);
 
     // The test document has four buttons:
     // HideScriptButton -> Hides targets with JavaScript
@@ -59,11 +59,10 @@ void VisibilityTest::initTestCase()
     //
     // With two radio buttons named TargetRadio.
 
-    const Okular::Page* page = m_document->page( 0 );
+    const Okular::Page *page = m_document->page(0);
     const QLinkedList<Okular::FormField *> pageFormFields = page->formFields();
-    for ( Okular::FormField *ff : pageFormFields )
-    {
-        m_fields.insert( ff->name(),  ff );
+    for (Okular::FormField *ff : pageFormFields) {
+        m_fields.insert(ff->name(), ff);
     }
 }
 
@@ -73,12 +72,12 @@ void VisibilityTest::cleanupTestCase()
     delete m_document;
 }
 
-void VisibilityTest::verifyTargetStates( bool visible )
+void VisibilityTest::verifyTargetStates(bool visible)
 {
-    QCOMPARE( m_fields[QStringLiteral( "TargetButton" )]->isVisible(), visible );
-    QCOMPARE( m_fields[QStringLiteral( "TargetText" )]->isVisible(), visible );
-    QCOMPARE( m_fields[QStringLiteral( "TargetCheck" )]->isVisible(), visible );
-    QCOMPARE( m_fields[QStringLiteral( "TargetDropDown" )]->isVisible(), visible );
+    QCOMPARE(m_fields[QStringLiteral("TargetButton")]->isVisible(), visible);
+    QCOMPARE(m_fields[QStringLiteral("TargetText")]->isVisible(), visible);
+    QCOMPARE(m_fields[QStringLiteral("TargetCheck")]->isVisible(), visible);
+    QCOMPARE(m_fields[QStringLiteral("TargetDropDown")]->isVisible(), visible);
 
     // Radios do not properly inherit a name from the parent group so
     // this does not work yet (And would probably need some list handling).
@@ -90,20 +89,20 @@ void VisibilityTest::testJavaScriptVisibility()
 #ifndef HAVE_POPPLER_0_64
     return;
 #endif
-    auto hideBtn = m_fields[QStringLiteral( "HideScriptButton" )];
-    auto showBtn = m_fields[QStringLiteral( "ShowScriptButton" )];
+    auto hideBtn = m_fields[QStringLiteral("HideScriptButton")];
+    auto showBtn = m_fields[QStringLiteral("ShowScriptButton")];
 
     // We start with all fields visible
-    verifyTargetStates( true );
+    verifyTargetStates(true);
 
-    m_document->processAction( hideBtn->activationAction() );
+    m_document->processAction(hideBtn->activationAction());
 
     // Now all should be hidden
-    verifyTargetStates( false );
+    verifyTargetStates(false);
 
     // And show again
-    m_document->processAction( showBtn->activationAction() );
-    verifyTargetStates( true );
+    m_document->processAction(showBtn->activationAction());
+    verifyTargetStates(true);
 }
 
 void VisibilityTest::testSaveLoad()
@@ -111,39 +110,37 @@ void VisibilityTest::testSaveLoad()
 #ifndef HAVE_POPPLER_0_64
     return;
 #endif
-    auto hideBtn = m_fields[QStringLiteral( "HideScriptButton" )];
-    auto showBtn = m_fields[QStringLiteral( "ShowScriptButton" )];
+    auto hideBtn = m_fields[QStringLiteral("HideScriptButton")];
+    auto showBtn = m_fields[QStringLiteral("ShowScriptButton")];
 
     // We start with all fields visible
-    verifyTargetStates( true );
+    verifyTargetStates(true);
 
-    m_document->processAction( hideBtn->activationAction() );
+    m_document->processAction(hideBtn->activationAction());
 
     // Now all should be hidden
-    verifyTargetStates( false );
+    verifyTargetStates(false);
 
     // Save the changed states
-    QTemporaryFile saveFile( QStringLiteral( "%1/okrXXXXXX.pdf" ).arg( QDir::tempPath() ) );
-    QVERIFY( saveFile.open() );
+    QTemporaryFile saveFile(QStringLiteral("%1/okrXXXXXX.pdf").arg(QDir::tempPath()));
+    QVERIFY(saveFile.open());
     saveFile.close();
 
-    QVERIFY( m_document->saveChanges( saveFile.fileName() ) );
+    QVERIFY(m_document->saveChanges(saveFile.fileName()));
 
-    auto newDoc = new Okular::Document( nullptr );
+    auto newDoc = new Okular::Document(nullptr);
 
     QMimeDatabase db;
-    const QMimeType mime = db.mimeTypeForFile( saveFile.fileName() );
-    QCOMPARE( newDoc->openDocument( saveFile.fileName(), QUrl(), mime), Okular::Document::OpenSuccess );
+    const QMimeType mime = db.mimeTypeForFile(saveFile.fileName());
+    QCOMPARE(newDoc->openDocument(saveFile.fileName(), QUrl(), mime), Okular::Document::OpenSuccess);
 
-    const Okular::Page* page = newDoc->page( 0 );
+    const Okular::Page *page = newDoc->page(0);
 
     bool anyChecked = false; // Saveguard against accidental test passing here ;-)
     const QLinkedList<Okular::FormField *> pageFormFields = page->formFields();
-    for ( Okular::FormField *ff: pageFormFields )
-    {
-        if ( ff->name().startsWith( QStringLiteral( "Target" ) ) )
-        {
-            QVERIFY( !ff->isVisible() );
+    for (Okular::FormField *ff : pageFormFields) {
+        if (ff->name().startsWith(QStringLiteral("Target"))) {
+            QVERIFY(!ff->isVisible());
             anyChecked = true;
         }
     }
@@ -153,7 +150,7 @@ void VisibilityTest::testSaveLoad()
     delete newDoc;
 
     // Restore the state of the member document
-    m_document->processAction( showBtn->activationAction() );
+    m_document->processAction(showBtn->activationAction());
 }
 
 void VisibilityTest::testActionVisibility()
@@ -161,19 +158,19 @@ void VisibilityTest::testActionVisibility()
 #ifndef HAVE_POPPLER_0_64
     return;
 #endif
-    auto hideBtn = m_fields[QStringLiteral( "HideActionButton" )];
-    auto showBtn = m_fields[QStringLiteral( "ShowActionButton" )];
+    auto hideBtn = m_fields[QStringLiteral("HideActionButton")];
+    auto showBtn = m_fields[QStringLiteral("ShowActionButton")];
 
-    verifyTargetStates( true );
+    verifyTargetStates(true);
 
-    m_document->processAction( hideBtn->activationAction() );
+    m_document->processAction(hideBtn->activationAction());
 
-    verifyTargetStates( false );
+    verifyTargetStates(false);
 
-    m_document->processAction( showBtn->activationAction() );
+    m_document->processAction(showBtn->activationAction());
 
-    verifyTargetStates( true );
+    verifyTargetStates(true);
 }
 
-QTEST_MAIN( VisibilityTest )
+QTEST_MAIN(VisibilityTest)
 #include "visibilitytest.moc"
