@@ -17,29 +17,35 @@
 #include <QtTextToSpeech>
 #endif
 
-DlgAccessibility::DlgAccessibility( QWidget * parent )
-    : QWidget( parent ), m_selected( 0 )
+DlgAccessibility::DlgAccessibility(QWidget *parent)
+    : QWidget(parent)
+    , m_selected(0)
 {
     m_dlg = new Ui_DlgAccessibilityBase();
-    m_dlg->setupUi( this );
+    m_dlg->setupUi(this);
 
     // ### not working yet, hide for now
     m_dlg->kcfg_HighlightImages->hide();
 
-    m_color_pages.append( m_dlg->page_invert );
-    m_color_pages.append( m_dlg->page_paperColor );
-    m_color_pages.append( m_dlg->page_darkLight );
-    m_color_pages.append( m_dlg->page_bw );
-    for ( QWidget *page : qAsConst(m_color_pages) ) {
+    m_color_pages.append(m_dlg->page_invert);
+    m_color_pages.append(m_dlg->page_paperColor);
+    m_color_pages.append(m_dlg->page_darkLight);
+    m_color_pages.append(m_dlg->page_bw);
+    m_color_pages.append(m_dlg->page_invertLightness);
+    m_color_pages.append(m_dlg->page_invertLuma);
+    m_color_pages.append(m_dlg->page_invertLumaSymmetric);
+    m_color_pages.append(m_dlg->page_hueShiftPositive);
+    m_color_pages.append(m_dlg->page_hueShiftNegative);
+    for (QWidget *page : qAsConst(m_color_pages)) {
         page->hide();
     }
-    m_color_pages[ m_selected ]->show();
+    m_color_pages[m_selected]->show();
 
 #ifdef HAVE_SPEECH
     // Populate tts engines
     const QStringList engines = QTextToSpeech::availableEngines();
-    for (const QString &engine: engines) {
-        m_dlg->kcfg_ttsEngine->addItem (engine);
+    for (const QString &engine : engines) {
+        m_dlg->kcfg_ttsEngine->addItem(engine);
     }
     m_dlg->kcfg_ttsEngine->setProperty("kcfg_property", QByteArray("currentText"));
 #else
@@ -54,10 +60,10 @@ DlgAccessibility::~DlgAccessibility()
     delete m_dlg;
 }
 
-void DlgAccessibility::slotColorMode( int mode )
+void DlgAccessibility::slotColorMode(int mode)
 {
-    m_color_pages[ m_selected ]->hide();
-    m_color_pages[ mode ]->show();
+    m_color_pages[m_selected]->hide();
+    m_color_pages[mode]->show();
 
     m_selected = mode;
 }
