@@ -10,22 +10,20 @@
 #include "shellutils.h"
 
 // qt/kde includes
-#include <QUrl>
+#include <QCommandLineParser>
+#include <QDebug>
+#include <QDir>
 #include <QFile>
 #include <QFileInfo>
-#include <QDir>
-#include <QDebug>
-#include <QCommandLineParser>
+#include <QUrl>
 
 namespace ShellUtils
 {
-
 namespace detail
 {
-
-bool qfileExistFunc( const QString& fileName )
+bool qfileExistFunc(const QString &fileName)
 {
-    return QFile::exists( fileName );
+    return QFile::exists(fileName);
 }
 
 }
@@ -35,38 +33,37 @@ FileExistFunc qfileExistFunc()
     return detail::qfileExistFunc;
 }
 
-QUrl urlFromArg( const QString& _arg, FileExistFunc exist_func, const QString& pageArg )
+QUrl urlFromArg(const QString &_arg, FileExistFunc exist_func, const QString &pageArg)
 {
     QUrl url = QUrl::fromUserInput(_arg, QDir::currentPath(), QUrl::AssumeLocalFile);
-    if ( url.isLocalFile() ) {
+    if (url.isLocalFile()) {
         // make sure something like /tmp/foo#bar.pdf is treated as a path name (default)
         // but something like /tmp/foo.pdf#bar is foo.pdf plus an anchor "bar"
         const QString path = url.path();
-        int hashIndex = path.lastIndexOf( QLatin1Char ( '#' ) );
-        if ( hashIndex != -1 && !exist_func(path) ) {
-            url.setPath( path.left( hashIndex ) );
-            url.setFragment( path.mid( hashIndex + 1 ) );
+        int hashIndex = path.lastIndexOf(QLatin1Char('#'));
+        if (hashIndex != -1 && !exist_func(path)) {
+            url.setPath(path.left(hashIndex));
+            url.setFragment(path.mid(hashIndex + 1));
         }
-    } else if ( !url.fragment().isEmpty() ) {
+    } else if (!url.fragment().isEmpty()) {
         // make sure something like http://example.org/foo#bar.pdf is treated as a path name
         // but something like http://example.org/foo.pdf#bar is foo.pdf plus an anchor "bar"
-        if ( url.fragment().contains( QLatin1Char( '.' ) ) ) {
-            url.setPath( url.path() + QLatin1Char ( '#' ) + url.fragment() );
-            url.setFragment( QString() );
+        if (url.fragment().contains(QLatin1Char('.'))) {
+            url.setPath(url.path() + QLatin1Char('#') + url.fragment());
+            url.setFragment(QString());
         }
     }
-    if ( !pageArg.isEmpty() )
-    {
-      url.setFragment( pageArg );
-    }  
+    if (!pageArg.isEmpty()) {
+        url.setFragment(pageArg);
+    }
     return url;
 }
 
 QString serializeOptions(const QCommandLineParser &args)
 {
-    const bool startInPresentation = args.isSet( QStringLiteral("presentation") );
-    const bool showPrintDialog = args.isSet( QStringLiteral("print") );
-    const bool showPrintDialogAndExit = args.isSet( QStringLiteral("print-and-exit") );
+    const bool startInPresentation = args.isSet(QStringLiteral("presentation"));
+    const bool showPrintDialog = args.isSet(QStringLiteral("print"));
+    const bool showPrintDialogAndExit = args.isSet(QStringLiteral("print-and-exit"));
     const bool unique = args.isSet(QStringLiteral("unique")) && args.positionalArguments().count() <= 1;
     const bool noRaise = args.isSet(QStringLiteral("noraise"));
     const QString page = args.value(QStringLiteral("page"));
@@ -84,8 +81,7 @@ bool unserializeOptions(const QString &serializedOptions, bool *presentation, bo
 {
     const QStringList args = serializedOptions.split(QStringLiteral(":"));
 
-    if (args.count() == 7)
-    {
+    if (args.count() == 7) {
         *presentation = args[0] == QLatin1String("1");
         *print = args[1] == QLatin1String("1");
         *print_and_exit = args[2] == QLatin1String("1");
